.. :changelog:

History
=======

1.0a2 (2017-05-04)
------------------

* Switched configuration format from RSON to YAML.
* Added support for jailing test runs.
* Added option for test visibility in report.

1.0a1 (unreleased)
------------------

* First usable version.
